@@ -1,8 +1,8 @@
 
-__version__ = "0.1.9"
+__version__ = "0.2.0"
 
 # The USGS API endpoint
-USGS_API = "https://earthexplorer.usgs.gov/inventory/soap"
+USGS_API = "https://earthexplorer.usgs.gov/inventory/json"
 
 #
 # Four catalogs are available for querying
@@ -20,7 +20,7 @@ EARTH_EXPLORER_CATALOG_NODE = "EE"
 HDDS_EXPLORER_CATALOG_NODE = "HDDS"
 
 # http://lpvsexplorer.cr.usgs.gov/
-LPVS_EXPLORER_CATALOG_NODE = "LPVS"
+LPCS_EXPLORER_CATALOG_NODE = "LPCS"
 
 class USGSError(Exception):
     pass
@@ -28,9 +28,6 @@ class USGSError(Exception):
 class USGSApiKeyRequiredError(Exception):
     pass
 
-class USGSCatalogNodeDoesNotExist(Exception):
-    pass
-
 class USGSAmbiguousNode(Exception):
     pass
 
